18. Citing Jscatter — Jscatter 1.2.0 documentation

# 18. Citing Jscatter

Jscatter paper (use this in a scientific paper)

> Biehl, R. (2019). Jscatter, a program for evaluation and analysis of experimental data. PLOS ONE, 14(6), e0218789. https://doi.org/10.1371/JOURNAL.PONE.0218789

Jscatter latest version at Zenodo (including version archive and history)

> Biehl Ralf. (2019). Jscatter, a Program for Evaluation and Analysis of Experimental Data. Zenodo. http://doi.org/10.5281/zenodo.1470306